aboutsummaryrefslogtreecommitdiffstats
path: root/Source/SPDatabaseCopy.h
diff options
context:
space:
mode:
Diffstat (limited to 'Source/SPDatabaseCopy.h')
-rw-r--r--Source/SPDatabaseCopy.h16
1 files changed, 4 insertions, 12 deletions
diff --git a/Source/SPDatabaseCopy.h b/Source/SPDatabaseCopy.h
index 081378e2..3adf7fa0 100644
--- a/Source/SPDatabaseCopy.h
+++ b/Source/SPDatabaseCopy.h
@@ -38,18 +38,10 @@
/**
* This method clones an existing database.
*
* @param NSString sourceDatabaseName the name of the source database
* @param NSString targetDatabaseName the name of the target database
* @result BOOL success
*/
-- (BOOL)copyDatabaseFrom:(NSString *)sourceDatabaseName to:(NSString *)targetDatabaseName withContent:(BOOL)copyWithContent;
-
-/**
- * This method creates a new database.
- *
- * @param NSString newDatabaseName name of the new database to be created
- * @return BOOL YES on success, otherwise NO
- */
-- (BOOL)createDatabase:(NSString *)newDatabaseName;
+- (BOOL)copyDatabaseFrom:(SPCreateDatabaseInfo *)sourceDatabase to:(NSString *)targetDatabaseName withContent:(BOOL)copyWithContent;
@end
@@ -38,18 +38,10 @@
* This method clones an existing database.
*
- * @param NSString sourceDatabaseName the name of the source database
- * @param NSString targetDatabaseName the name of the target database
- * @result BOOL success
+ * @param sourceDatabase information tuple about source database
+ * @param targetDatabaseName the name of the target database
+ * @result success
*/